==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/it.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Caricamento anteprima...",
    "Saved" : "Salvato",
    "Admin" : "Amministratore",
    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
    "Name cannot be empty" : "Il nome non può essere vuoto",
    "The given name is too long" : "Questo nome è troppo lungo",
    "The given web address is too long" : "Questo indirizzo web è troppo lungo",
    "The given legal notice address is too long" : "L'indirizzo dell'avviso legale specificato è troppo lungo",
    "The given privacy policy address is too long" : "L'indirizzo dello specifico criterio di riservatezza è troppo lungo",
    "The given slogan is too long" : "Questo slogan è troppo lungo",
    "The given color is invalid" : "Questo colore non è valido",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è  stato caricato solo parzialmente",
    "No file was uploaded" : "Non è stato caricato alcun file",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "No file uploaded" : "Nessun file caricato",
    "Unsupported image type" : "Tipo di immagine non supportato",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Stai già utilizzando un tema personalizzato. Le impostazioni dell'applicazione dei temi potrebbero essere sovrascritte.",
    "Theming" : "Tema",
    "Legal notice" : "Avviso legale",
    "Privacy policy" : "Criterio di riservatezza",
    "Adjust the Nextcloud theme" : "Modifica il tema di Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La gestione dei temi rende semplice la personalizzazione dell'aspetto della tua istanza e dei client supportati. Ciò sarà visibile a tutti gli utenti.",
    "Name" : "Nome",
    "Reset to default" : "Ripristina valori predefiniti",
    "Web link" : "Collegamento web",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Colore",
    "Logo" : "Logo",
    "Upload new logo" : "Carica nuovo logo",
    "Login image" : "Immagine di accesso",
    "Upload new login background" : "Carica nuovo sfondo di accesso",
    "Remove background image" : "Rimuovi immagine di sfondo",
    "Advanced options" : "Opzioni avanzate",
    "Legal notice link" : "Collegamento avviso legale",
    "Privacy policy link" : "Collegamento criterii di riservatezza",
    "Header logo" : "Logo dell'intestazione",
    "Upload new header logo" : "Carica nuovo logo dell'intestazione",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Carica nuova favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa l'estensione Imagemacick di PHP con supporto per le immagini SVG per generare automaticamente favicon basate sul logo caricato e sul colore.",
    "You are already using a custom theme" : "Stai già usando un tema personalizzato",
    "reset to default" : "ripristina valori predefiniti",
    "Web address" : "Indirizzo web",
    "Web address https://…" : "Indirizzo web https://…",
    "There is no error, the file uploaded with success" : "Non ci sono errori, il file è stato caricato correttamente",
    "The uploaded file was only partially uploaded" : "Il file è stato caricato solo parzialmente",
    "Failed to write file to disk." : "Scrittura su disco non riuscita",
    "A PHP extension stopped the file upload." : "Un'estensione PHP ha fermato il caricamento del file."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/it.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Caricamento anteprima...",
    "Saved" : "Salvato",
    "Admin" : "Amministratore",
    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
    "Name cannot be empty" : "Il nome non può essere vuoto",
    "The given name is too long" : "Questo nome è troppo lungo",
    "The given web address is too long" : "Questo indirizzo web è troppo lungo",
    "The given legal notice address is too long" : "L'indirizzo dell'avviso legale specificato è troppo lungo",
    "The given privacy policy address is too long" : "L'indirizzo dello specifico criterio di riservatezza è troppo lungo",
    "The given slogan is too long" : "Questo slogan è troppo lungo",
    "The given color is invalid" : "Questo colore non è valido",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è  stato caricato solo parzialmente",
    "No file was uploaded" : "Non è stato caricato alcun file",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "No file uploaded" : "Nessun file caricato",
    "Unsupported image type" : "Tipo di immagine non supportato",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Stai già utilizzando un tema personalizzato. Le impostazioni dell'applicazione dei temi potrebbero essere sovrascritte.",
    "Theming" : "Tema",
    "Legal notice" : "Avviso legale",
    "Privacy policy" : "Criterio di riservatezza",
    "Adjust the Nextcloud theme" : "Modifica il tema di Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La gestione dei temi rende semplice la personalizzazione dell'aspetto della tua istanza e dei client supportati. Ciò sarà visibile a tutti gli utenti.",
    "Name" : "Nome",
    "Reset to default" : "Ripristina valori predefiniti",
    "Web link" : "Collegamento web",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Colore",
    "Logo" : "Logo",
    "Upload new logo" : "Carica nuovo logo",
    "Login image" : "Immagine di accesso",
    "Upload new login background" : "Carica nuovo sfondo di accesso",
    "Remove background image" : "Rimuovi immagine di sfondo",
    "Advanced options" : "Opzioni avanzate",
    "Legal notice link" : "Collegamento avviso legale",
    "Privacy policy link" : "Collegamento criterii di riservatezza",
    "Header logo" : "Logo dell'intestazione",
    "Upload new header logo" : "Carica nuovo logo dell'intestazione",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Carica nuova favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa l'estensione Imagemacick di PHP con supporto per le immagini SVG per generare automaticamente favicon basate sul logo caricato e sul colore.",
    "There is no error, the file uploaded with success" : "Non ci sono errori, il file è stato caricato correttamente",
    "The uploaded file was only partially uploaded" : "Il file è stato caricato solo parzialmente",
    "Failed to write file to disk." : "Scrittura su disco non riuscita",
    "A PHP extension stopped the file upload." : "Un'estensione PHP ha fermato il caricamento del file.",
    "You are already using a custom theme" : "Stai già usando un tema personalizzato",
    "Web address https://…" : "Indirizzo web https://…"
},
"nplurals=2; plural=(n != 1);");
